@@ -10,10 +10,14 @@ var execute = function (x, done) {
       cb(err)
     })
   }
-  return async.timesSeries(5, query, ok(done, function () {
-    client.end()
-    done()
-  }))
+  return async.timesSeries(
+    5,
+    query,
+    ok(done, function () {
+      client.end()
+      done()
+    })
+  )
 }
 describe('Load tests', function () {
   it('single client and many queries', function (done) {
